addpath('lib')
addpath(fullfile('lib', 'bids'))
setup_paths

warning('off', 'MATLAB:MKDIR:DirectoryExists');
log_file = start_log(fullfile(deriv_path, 'logs'), mfilename);
spm('defaults','FMRI');

subjects = bids_get_subjects(nifti_path, 'full');
for i=1:length(subjects)
    subject = cell2mat(subjects(i));
    sessions = bids_get_sessions(nifti_path, subject);
    for j=1:length(sessions)
        session = cell2mat(sessions(j));
        tmpid = get_tmpid_s();
        in_dir = fullfile(deriv_path, 'MPM', subject, session);
        out_dir = fullfile(deriv_path, 'MPM', subject, session);
        mkdir(fullfile(out_dir, 'batches'));
        mkdir(fullfile(out_dir, 'logs'));
        mkdir(fullfile(out_dir, 'qMRIprocessed'));
        batchfile = fullfile(out_dir, 'batches', ['processmaps-', tmpid, '.mat']);
        batchlog = fullfile(out_dir, 'logs', ['processmaps-%j-', tmpid, '.log']);
        % compiled SPM does not work https://github.com/hMRI-group/hMRI-toolbox/issues/5
        %batchcmd = sprintf('%s %s batch %s', compiled_hmri, mcr_path, batchfile);
        batchcmd = sprintf(['. /etc/profile; module load matlab; matlab -r \\"' ...
                            'addpath(''%s''); ' ...
                            'addpath(genpath(''%s'')); ' ...
                            'spm(''defaults'', ''fmri''); ' ...
                            'spm_jobman(''initcfg''); ' ...
                            'load(''%s''); ' ...
                            'spm_jobman(''run'', matlabbatch); ' ...
                            'quit;\\"'], ...
                            spm_with_hmri, ...
                            fullfile(spm_with_hmri, 'toolbox', 'hMRI'), ...
                            batchfile);

        files=cell(1,5);

        if exist(fullfile(out_dir, 'qMRIprocessed', 'Template_0.nii'))
            fprintf('qMRI template already exist, skipping %s/%s\n', subject, session);
        else

            % FIXME: only pick the first image here? (initially this was MT/magnitude/*.nii)
            files{1} = spm_select('FPList', fullfile(in_dir, 'reorient_MT', 'AutoReorient'), '^.*01\.nii$');

            map1 = spm_select('FPList', fullfile(in_dir, 'qMRImaps', 'Results'), '^.*\MTsat\.nii$');
            map2 = spm_select('FPList', fullfile(in_dir, 'qMRImaps', 'Results'), '^.*\PD\.nii$');
            map3 = spm_select('FPList', fullfile(in_dir, 'qMRImaps', 'Results'), '^.*\R1\.nii$');
            map4 = spm_select('FPList', fullfile(in_dir, 'qMRImaps', 'Results'), '^.*\R2s_OLS\.nii$');
            files{2} = { cellstr(map1), cellstr(map2), cellstr(map3), cellstr(map4) };


            fprintf('Creating batch for %s/%s ...\n', subject, session);
            clear matlabbatch
            matlabbatch{1}.spm.tools.hmri.proc.proc_pipel.output.outdir = {fullfile(out_dir, 'qMRIprocessed')};
            matlabbatch{1}.spm.tools.hmri.proc.proc_pipel.s_vols = cellstr(files{1});
            matlabbatch{1}.spm.tools.hmri.proc.proc_pipel.vols_pm = files{2};
            matlabbatch{1}.spm.tools.hmri.proc.proc_pipel.vox = [1 1 1];
            matlabbatch{1}.spm.tools.hmri.proc.proc_pipel.bb = [-78 -112 -70; 78 76 85];
            matlabbatch{1}.spm.tools.hmri.proc.proc_pipel.fwhm = [6 6 6];
            matlabbatch{1}.spm.tools.hmri.proc.proc_pipel.pipe_c = 2;

            save(batchfile, 'matlabbatch');

            fprintf('Submitting\n');
            system(sprintf('sbatch -D. -c 1 -J %s -o %s --wrap "%s"', ...
                        ['processmaps_', subject, '_', session], ...
                        batchlog, batchcmd));
        end
    end % session
end % subject
stop_log(log_file);
